import NextAuth, { NextAuthOptions } from "next-auth";
import KeycloakProvider from "next-auth/providers/keycloak"


import {
  authJwtSecret,
  providerClientId,
  providerClientSecret,
  providerIssuer,
} from "../../../utils/env";

// TODO: handle refresh token
export const authOptions: NextAuthOptions = {
  debug: true,
  session: { strategy: "jwt" },
  secret: authJwtSecret,
  providers: [
    KeycloakProvider({
      clientId: providerClientId,
      clientSecret: providerClientSecret,
      issuer: providerIssuer,
    }),  
  ],
  callbacks: {
    // checks whether user is allowed to sign in
    async signIn({ account }) {
      return true;
    },

    async jwt({ token, account, profile }) {
        const email = (profile as any)?.email;
        const did = (profile as any)?.given_name;
    
        return {
        ...token,
        ...(email && { email }),
        ...(did && { did }),
        ...(account?.access_token && { accessToken: account?.access_token }),
        ...(account?.id_token && { idToken: account?.id_token }),
        ...(profile?.sub && { userId: profile?.sub }),
        };
    },
    
    async session({ session, token }) {
        return {
        ...session,
        ...session.user,
        ...(token.did && { did: token.did }),
        ...(token.email && { email: token.email }),
        ...(token.userId && { userId: token.userId }),
        ...(token.accessToken && { accessToken: token.accessToken }),
        ...(token.idToken && { idToken: token.idToken }),
        };
    },  
  } 
};

export default NextAuth(authOptions);
